@@ -1,5 +1,6 @@
-use std::error::Error;
+use std::{error::Error, ops::Sub};
 
+use chrono::Duration;
 use termion::{
     color::{self, Color},
     event::Key,
@@ -62,7 +63,7 @@ impl<'a> Token<'a> {
             terminal.set_bg_color(color.as_ref())?;
         }
         if let Some(style) = &self.style {
-            terminal.set_style(style.clone())?;
+            terminal.set_style(*style)?;
         }
 
         terminal.write(self.content)?;
@@ -218,6 +219,104 @@ impl<'a> Renderer<'a> {
         Ok(())
     }
 
+    #[cfg(feature = "date")]
+    pub fn print_calendar_month(
+        &mut self,
+        month: chrono::Month,
+        year: i32,
+        week_start: chrono::Weekday,
+        today: chrono::NaiveDate,
+        selected_date: chrono::NaiveDate,
+        min_date: Option<chrono::NaiveDate>,
+        max_date: Option<chrono::NaiveDate>,
+    ) -> Result<(), std::io::Error> {
+        use crate::date_utils::get_start_date;
+        use chrono::Datelike;
+
+        // print header (month year)
+        let header = format!("{} {}", month.name().to_lowercase(), year);
+
+        self.print_tokens(&vec![
+            Token::new("> ").with_fg(color::Green),
+            Token::new(&format!("{:^20}", header)),
+        ])?;
+        self.new_line()?;
+
+        // print week header
+        let mut current_weekday = week_start;
+        let mut week_days: Vec<String> = vec![];
+        for _ in 0..7 {
+            let mut formatted = format!("{}", current_weekday);
+            formatted.make_ascii_lowercase();
+            formatted.pop();
+            week_days.push(formatted);
+
+            current_weekday = current_weekday.succ();
+        }
+        let week_days = week_days.join(" ");
+
+        Token::new("> ")
+            .with_fg(color::Green)
+            .print(&mut self.terminal)?;
+        self.terminal.write(&week_days)?;
+        self.new_line()?;
+
+        // print dates
+        let mut date_it = get_start_date(month, year);
+        // first date of week-line is possibly in the previous month
+        if date_it.weekday() == week_start {
+            date_it = date_it.sub(Duration::weeks(1));
+        } else {
+            while date_it.weekday() != week_start {
+                date_it = date_it.pred();
+            }
+        }
+
+        for _ in 0..6 {
+            Token::new("> ")
+                .with_fg(color::Green)
+                .print(&mut self.terminal)?;
+
+            for i in 0..7 {
+                if i > 0 {
+                    self.terminal.write(" ")?;
+                }
+
+                let date = format!("{:2}", date_it.day());
+
+                let mut token = Token::new(&date);
+
+                if date_it == selected_date {
+                    token = token.with_bg(color::LightWhite).with_fg(color::Black);
+                } else if date_it == today {
+                    token = token.with_fg(color::Green);
+                } else if date_it.month() != month.number_from_month() {
+                    token = token.with_fg(color::LightBlack);
+                }
+
+                if let Some(min_date) = min_date {
+                    if date_it < min_date {
+                        token = token.with_fg(color::LightBlack);
+                    }
+                }
+
+                if let Some(max_date) = max_date {
+                    if date_it > max_date {
+                        token = token.with_fg(color::LightBlack);
+                    }
+                }
+
+                token.print(&mut self.terminal)?;
+
+                date_it = date_it.succ();
+            }
+
+            self.new_line()?;
+        }
+
+        Ok(())
+    }
+
     pub fn cleanup(&mut self, message: &str, answer: &str) -> Result<(), Box<dyn Error>> {
         self.reset_prompt()?;
         self.print_prompt_answer(message, answer)?;
